Index: main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_browser.py
===================================================================
--- main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_browser.py	(revision 12037)
+++ main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_browser.py	(revision 12038)
@@ -333,17 +333,17 @@
         self.browser.open(self.manage_customer_path)
         image = open(SAMPLE_IMAGE_BMP, 'rb')
-        ctrl = self.browser.getControl(name='passportuploadmanage')
+        ctrl = self.browser.getControl(name='passportmanageupload')
         file_ctrl = ctrl.mech_control
         file_ctrl.add_file(image, filename='my_photo.bmp')
         self.browser.getControl(
-            name='upload_passportuploadmanage').click()
+            name='upload_passportmanageupload').click()
         self.assertTrue('jpg file extension expected'
             in self.browser.contents)
-        ctrl = self.browser.getControl(name='passportuploadmanage')
+        ctrl = self.browser.getControl(name='passportmanageupload')
         file_ctrl = ctrl.mech_control
         image = open(SAMPLE_IMAGE, 'rb')
         file_ctrl.add_file(image, filename='my_photo.jpg')
         self.browser.getControl(
-            name='upload_passportuploadmanage').click()
+            name='upload_passportmanageupload').click()
         self.assertTrue(
             'src="http://localhost/app/customers/K1000000/passport.jpg"'
@@ -561,10 +561,10 @@
         # Admitted customer can upload a passport picture
         self.browser.getLink("Change portrait").click()
-        ctrl = self.browser.getControl(name='passportuploadedit')
+        ctrl = self.browser.getControl(name='passporteditupload')
         file_obj = open(SAMPLE_IMAGE, 'rb')
         file_ctrl = ctrl.mech_control
         file_ctrl.add_file(file_obj, filename='my_photo.jpg')
         self.browser.getControl(
-            name='upload_passportuploadedit').click()
+            name='upload_passporteditupload').click()
         self.assertTrue(
             'src="http://localhost/app/customers/K1000000/passport.jpg"'
@@ -786,7 +786,7 @@
         self.browser.getLink("Documents").click()
         self.browser.getLink("Add document").click()
-        self.browser.getControl(name="doctype").value = ['generic']
+        self.browser.getControl(name="doctype").value = ['sample']
         self.browser.getControl("Create document").click()
-        self.assertTrue('Generic Document created.' in self.browser.contents)
+        self.assertTrue('Sample Document created.' in self.browser.contents)
         document = self.customer['documents']['d102']
 
@@ -827,5 +827,5 @@
         self.assertTrue(
             'INFO - zope.mgr - customers.browser.DocumentAddFormPage '
-            '- K1000000 - added: Generic Document %s'
+            '- K1000000 - added: Sample Document %s'
             % document.document_id in logcontent)
 
@@ -845,7 +845,7 @@
         self.browser.getLink("Documents").click()
         self.browser.getLink("Add document").click()
-        self.browser.getControl(name="doctype").value = ['generic']
+        self.browser.getControl(name="doctype").value = ['sample']
         self.browser.getControl("Create document").click()
-        self.assertTrue('Generic Document created.' in self.browser.contents)
+        self.assertTrue('Sample Document created.' in self.browser.contents)
         document = self.customer['documents']['d102']
 
@@ -866,12 +866,12 @@
         # Costumer can upload a document.
         self.browser.getLink("Edit").click()
-        ctrl = self.browser.getControl(name='genericuploadedit')
+        ctrl = self.browser.getControl(name='scaneditupload')
         file_obj = open(SAMPLE_IMAGE, 'rb')
         file_ctrl = ctrl.mech_control
         file_ctrl.add_file(file_obj, filename='my_document.jpg')
         self.browser.getControl(
-            name='upload_genericuploadedit').click()
-        self.assertTrue(
-            'href="http://localhost/app/customers/K1000000/documents/d102/generic"'
+            name='upload_scaneditupload').click()
+        self.assertTrue(
+            'href="http://localhost/app/customers/K1000000/documents/d102/scan"'
             in self.browser.contents)
         # Costumer can submit the form. The form is also saved.
@@ -890,27 +890,26 @@
         self.browser.addHeader('Authorization', 'Basic mgr:mgrpw')
         self.browser.open(self.customer_path + '/documents/d101/manage')
-        # Create a pseudo image file and select it to be uploaded in form
-        # as generic document
+        # Create a pseudo image file and select it to be uploaded 
         image = open(SAMPLE_IMAGE, 'rb')
-        ctrl = self.browser.getControl(name='genericuploadmanage')
+        ctrl = self.browser.getControl(name='scanmanageupload')
         file_ctrl = ctrl.mech_control
-        file_ctrl.add_file(image, filename='my_generic_document.jpg')
+        file_ctrl.add_file(image, filename='my_scan.jpg')
         # The Save action does not upload files
         self.browser.getControl("Save").click() # submit form
         self.assertFalse(
-            'href="http://localhost/app/customers/K1000000/documents/d101/generic"'
+            'href="http://localhost/app/customers/K1000000/documents/d101/scan"'
             in self.browser.contents)
         # ... but the correct upload submit button does
         image = open(SAMPLE_IMAGE)
-        ctrl = self.browser.getControl(name='genericuploadmanage')
+        ctrl = self.browser.getControl(name='scanmanageupload')
         file_ctrl = ctrl.mech_control
-        file_ctrl.add_file(image, filename='my_generic_document.jpg')
-        self.browser.getControl(
-            name='upload_genericuploadmanage').click()
-        self.assertTrue(
-            'href="http://localhost/app/customers/K1000000/documents/d101/generic"'
+        file_ctrl.add_file(image, filename='my_scan.jpg')
+        self.browser.getControl(
+            name='upload_scanmanageupload').click()
+        self.assertTrue(
+            'href="http://localhost/app/customers/K1000000/documents/d101/scan"'
             in self.browser.contents)
         # Browsing the link shows a real image
-        self.browser.open('generic')
+        self.browser.open('scan')
         self.assertEqual(
             self.browser.headers['content-type'], 'image/jpeg')
@@ -919,40 +918,40 @@
         self.browser.open(self.customer_path + '/documents/d101/manage')
         self.assertFalse(
-            'upload_genericuploadmanage' in self.browser.contents)
+            'upload_scanmanageupload' in self.browser.contents)
         # File must be deleted first
-        self.browser.getControl(name='delete_genericuploadmanage').click()
-        self.assertTrue(
-            'generic deleted' in self.browser.contents)
+        self.browser.getControl(name='delete_scanmanageupload').click()
+        self.assertTrue(
+            'scan deleted' in self.browser.contents)
         # Uploading a file which is bigger than 150k will raise an error
         big_image = StringIO(open(SAMPLE_IMAGE, 'rb').read() * 75)
-        ctrl = self.browser.getControl(name='genericuploadmanage')
+        ctrl = self.browser.getControl(name='scanmanageupload')
         file_ctrl = ctrl.mech_control
-        file_ctrl.add_file(big_image, filename='my_generic_document.jpg')
-        self.browser.getControl(
-            name='upload_genericuploadmanage').click()
+        file_ctrl.add_file(big_image, filename='my_scan.jpg')
+        self.browser.getControl(
+            name='upload_scanmanageupload').click()
         self.assertTrue(
             'Uploaded file is too big' in self.browser.contents)
         # we do not rely on filename extensions given by uploaders
         image = open(SAMPLE_IMAGE, 'rb') # a jpg-file
-        ctrl = self.browser.getControl(name='genericuploadmanage')
+        ctrl = self.browser.getControl(name='scanmanageupload')
         file_ctrl = ctrl.mech_control
         # tell uploaded file is bmp
-        file_ctrl.add_file(image, filename='my_generic_document.bmp')
-        self.browser.getControl(
-            name='upload_genericuploadmanage').click()
+        file_ctrl.add_file(image, filename='my_scan.bmp')
+        self.browser.getControl(
+            name='upload_scanmanageupload').click()
         self.assertTrue(
             # jpg file was recognized
-            'File generic.jpg uploaded.' in self.browser.contents)
+            'File scan.jpg uploaded.' in self.browser.contents)
         # Delete file again
-        self.browser.getControl(name='delete_genericuploadmanage').click()
-        self.assertTrue(
-            'generic deleted' in self.browser.contents)
+        self.browser.getControl(name='delete_scanmanageupload').click()
+        self.assertTrue(
+            'scan deleted' in self.browser.contents)
         # File names must meet several conditions
         bmp_image = open(SAMPLE_IMAGE_BMP, 'rb')
-        ctrl = self.browser.getControl(name='genericuploadmanage')
+        ctrl = self.browser.getControl(name='scanmanageupload')
         file_ctrl = ctrl.mech_control
-        file_ctrl.add_file(bmp_image, filename='my_generic_document.bmp')
-        self.browser.getControl(
-            name='upload_genericuploadmanage').click()
+        file_ctrl.add_file(bmp_image, filename='my_scan.bmp')
+        self.browser.getControl(
+            name='upload_scanmanageupload').click()
         self.assertTrue('Only the following extensions are allowed'
             in self.browser.contents)

Index: main/waeup.ikoba/trunk/src/waeup/ikoba/customers/files.py
===================================================================
--- main/waeup.ikoba/trunk/src/waeup/ikoba/customers/files.py	(revision 12037)
+++ main/waeup.ikoba/trunk/src/waeup/ikoba/customers/files.py	(revision 12038)
@@ -226,5 +226,5 @@
 
 
-class PassportUploadManage(FileUpload):
+class PassportManageUpload(FileUpload):
     """Passport upload viewlet for officers.
     """
@@ -240,5 +240,5 @@
 
 
-class PassportUploadEdit(PassportUploadManage):
+class PassportEditUpload(PassportManageUpload):
     """Passport upload viewlet for customers.
     """
@@ -257,6 +257,6 @@
 # File viewlets for customer documents
 
-class GenericUploadManage(FileUpload):
-    """Generic document upload viewlet for officers.
+class ScanManageUpload(FileUpload):
+    """Scan upload viewlet for officers.
     """
     grok.order(1)
@@ -264,13 +264,13 @@
     grok.view(DocumentManageFormPage)
     grok.require('waeup.manageCustomer')
-    label = _(u'Generic Document')
-    title = _(u'Generic Document')
+    label = _(u'Scan')
+    title = _(u'Scan')
     mus = 1024 * 50
-    download_name = u'generic'
+    download_name = u'scan'
     tab_redirect = '#tab2'
 
 
-class GenericUploadEdit(GenericUploadManage):
-    """Generic document upload viewlet for customer.
+class ScanEditUpload(ScanManageUpload):
+    """Scan upload viewlet for customer.
     """
     grok.view(DocumentEditFormPage)
@@ -278,6 +278,6 @@
 
 
-class GenericDisplay(FileDisplay):
-    """Genreric document display viewlet.
+class ScanDisplay(FileDisplay):
+    """Scan display viewlet.
     """
     grok.order(1)
@@ -285,14 +285,14 @@
     grok.require('waeup.viewCustomer')
     grok.view(DocumentDisplayFormPage)
-    label = _(u'Generic Document')
-    title = _(u'Generic Document')
-    download_name = u'generic'
-
-
-class GenericImage(Image):
-    """Generic document.
-    """
-    grok.name('generic')
+    label = _(u'Scan')
+    title = _(u'Scan')
+    download_name = u'scan'
+
+
+class ScanImage(Image):
+    """Scan document.
+    """
+    grok.name('scan')
     grok.context(ICustomerDocument)
     grok.require('waeup.viewCustomer')
-    download_name = u'generic'
+    download_name = u'scan'